[−][src]Enum texture::Wrap
Wrap mode
Variants
RepeatRepeats the texture by ignoring the integer part of the coordinate.
MirroredRepeatRepeats the texture and mirrors it, when the integer part of the coordinate is odd.
ClampToEdgeThe coordinate will be clamped between 0 and 1.
ClampToBorderCoordinates outside the range [0.0, 1.0] will be given a border color.